@@ -1,7 +1,7 @@
 #!/usr/bin/runhaskell
 
 import Distribution.Simple
-import System.Cmd
+import System.Process
 import System.Exit
 
 main = defaultMainWithHooks simpleUserHooks
